import asyncio
from threading import Thread
from asyncio import coroutine

# Getting loop.
try:
    _goroutine_loop = asyncio.get_event_loop()
except:
    _goroutine_loop = asyncio.new_event_loop()
    asyncio.set_event_loop(_goroutine_loop)


def _run() -> None:
    '''
    Start loop.
    '''
    _goroutine_loop.run_forever()


def go(obj: callable, *args) -> None:
    '''
    Run a coroutine or a func asynchronously.
    Easy concurrency in Python.
    Args:
        obj: Takes coroutine function as object.
        *args: Arguments for your obj.
               You can also use functools.partial() for your func.
    Return:
        None
    '''
    # If a coroutine function run this.
    if callable(obj) and asyncio.iscoroutinefunction(obj):
        future = asyncio.run_coroutine_threadsafe(obj(*args), _goroutine_loop)
    else:
        raise TypeError('A coroutine function object is required')


# Run the loop in a thread.
T = Thread(target=_run, daemon=True)
T.start()



from enum import Enum

class Events(Enum):
    WAREHOUSE_CALLS = 'WAREHOUSE_CALLS_DATA'
    WAREHOUSE_TCN = 'WAREHOUSE_TCN_DATA'
    WAREHOUSE_LEADS = 'WAREHOUSE_LEADS_DATA'
    WAREHOUSE_COST_TRACKER = 'WAREHOUSE_COST_TRACKER'

class Service(Enum):
    ASR = "ASR"
    TTS = "TTS"
    SLU = "SLU"
    SMS = "SMS"
    TELEPHONY = "TELEPHONY"

class Vendor(Enum):
    NONE = "NONE"
    GOOGLE = "GOOGLE"
    SKIT = "SKIT"
    AZURE = "AZURE"
    AMAZON = "AMAZON"
    TCN = "TCN"
    TWILIO = "TWILIO"
    FAST2SMS = "FAST2SMS"
    TWO_FA = "TWO_FA"
    MY_OPERATOR = "MY_OPERATOR"
    MSG91 = "MSG91"
